@@ -7,7 +7,6 @@ import tzlocal
 from apscheduler.jobstores.sqlalchemy import SQLAlchemyJobStore
 from apscheduler.schedulers.background import BackgroundScheduler
 from apscheduler.triggers.cron import CronTrigger
-from apscheduler.triggers.interval import IntervalTrigger
 
 from flexget.config_schema import register_config_key, format_checker
 from flexget.event import event
@@ -102,10 +101,18 @@ def setup_scheduler(manager):
     global scheduler
     if logging.getLogger().getEffectiveLevel() > logging.DEBUG:
         logging.getLogger('apscheduler').setLevel(logging.WARNING)
-    jobstores = {'default': FlexGetJobStore(engine=manager.engine, metadata=Base.metadata)}
+    jobstores = {'default': SQLAlchemyJobStore(engine=manager.engine, metadata=Base.metadata)}
     # If job was meant to run within last day while daemon was shutdown, run it once when continuing
     job_defaults = {'coalesce': True, 'misfire_grace_time': 60 * 60 * 24}
-    scheduler = BackgroundScheduler(jobstores=jobstores, job_defaults=job_defaults)
+    timezone = tzlocal.get_localzone()
+    if timezone.zone == 'local':
+        # The default sqlalchemy jobstore does not work when there isn't a name for the local timezone.
+        # Just fall back to utc in this case
+        # FlexGet #2741, upstream ticket https://bitbucket.org/agronholm/apscheduler/issue/59
+        log.info('Local timezone name could not be determined. Scheduler will display times in UTC for any log'
+                 'messages. To resolve this set up /etc/timezone with correct time zone name.')
+        timezone = pytz.utc
+    scheduler = BackgroundScheduler(jobstores=jobstores, job_defaults=job_defaults, timezone=timezone)
     setup_jobs(manager)
 
 
@@ -129,14 +136,14 @@ def setup_jobs(manager):
         if jid in existing_job_ids:
             continue
         if 'interval' in job_config:
-            trigger = IntervalTrigger(**job_config['interval'])
+            trigger, trigger_args = 'interval', job_config['interval']
         else:
-            trigger = CronTrigger(**job_config['schedule'])
+            trigger, trigger_args = 'cron', job_config['schedule']
         tasks = job_config['tasks']
         if not isinstance(tasks, list):
             tasks = [tasks]
         name = ','.join(tasks)
-        scheduler.add_job(run_job, trigger=trigger, args=(tasks,), id=jid, name=name)
+        scheduler.add_job(run_job, args=(tasks,), id=jid, name=name, trigger=trigger, **trigger_args)
     # Remove jobs no longer in config
     for jid in existing_job_ids:
         if jid not in configured_job_ids:
@@ -146,32 +153,6 @@ def setup_jobs(manager):
         scheduler.start()
 
 
-class FlexGetJobStore(SQLAlchemyJobStore):
-    """
-    The default sqlalchemy jobstore does not work when there isn't a name for the local timezone.
-    This just translates the time to utc before storage.
-    FlexGet #2741, upstream ticket https://bitbucket.org/agronholm/apscheduler/issue/59
-    """
-    def __init__(self, *args, **kwargs):
-        super(FlexGetJobStore, self).__init__(*args, **kwargs)
-        if tzlocal.get_localzone().zone == 'local':
-            log.warning('Timezone name could not be determined. Scheduler will display times in UTC for any log'
-                        'messages. To resolve this set up /etc/timezone with correct time zone name.')
-            self.use_utc = True
-        else:
-            self.use_utc = False
-
-    def add_job(self, job):
-        if self.use_utc:
-            job.next_run_time = job.next_run_time.astimezone(pytz.utc)
-        super(FlexGetJobStore, self).add_job(job)
-
-    def update_job(self, job):
-        if self.use_utc:
-            job.next_run_time = job.next_run_time.astimezone(pytz.utc)
-        super(FlexGetJobStore, self).update_job(job)
-
-
 @event('manager.daemon.completed')
 def stop_scheduler(manager):
     if scheduler.running:
